@@ -36,10 +36,14 @@
 #define _GETDNS_EXTRA_H_
 
 #include <getdns/getdns.h>
-#include <sys/time.h>
-#include <stdio.h>
-#include <time.h>
 #include <stdarg.h>
+#include <stdio.h>
+#if defined(_WIN32)
+/* For struct timeval, see getdns_context_get_num_pending_requests */
+#include <winsock2.h>
+#else
+#include <sys/time.h>
+#endif
 
 #ifdef __cplusplus
 extern "C" {
@@ -120,10 +124,11 @@ extern "C" {
  * \defgroup versions Version values
  *  @{
  */
-#define GETDNS_VERSION "1.5.1"
-#define GETDNS_NUMERIC_VERSION 0x01050100
+#define GETDNS_VERSION "1.7.2"
+#define GETDNS_NUMERIC_VERSION 0x01070200
 #define GETDNS_API_VERSION "December 2015"
 #define GETDNS_API_NUMERIC_VERSION 0x07df0c00
+#define GETDNS_BUILD_CFLAGS "-march=armv8-a -O2 -pipe -fstack-protector-strong -fno-plt -fexceptions         -Wp,-D_FORTIFY_SOURCE=2 -Wformat -Werror=format-security         -fstack-clash-protection -D_POSIX_C_SOURCE=200112L -D_XOPEN_SOURCE=600 -D_BSD_SOURCE -D_DEFAULT_SOURCE -O3 -DNDEBUG"
 /** @}
   */
 
@@ -536,6 +541,18 @@ getdns_context_set_tls_query_padding_blocksize(getdns_context *context, uint16_t
 getdns_return_t
 getdns_context_unset_edns_maximum_udp_payload_size(getdns_context *context);
 
+/**
+ * Configure context to use the system default setting for the time
+ * send data may remain unacknowledged by the peer in a TCP connection.
+ * @see getdns_context_set_tcp_send_timeout
+ * @see getdns_context_get_tcp_send_timeout
+ * @param context The context to configure
+ * @return GETDNS_RETURN_GOOD on success
+ * @return GETDNS_RETURN_INVALID_PARAMETER if context is null.
+ */
+getdns_return_t
+getdns_context_unset_tcp_send_timeout(getdns_context *context);
+
 
 typedef enum getdns_loglevel_type {
 	GETDNS_LOG_EMERG   = 0,
@@ -609,7 +626,7 @@ getdns_context_set_logfunc(getdns_context *context, void *userarg,
  *                        store data.  The last element of the path is tried
  *                        to be created if it does not exist.  When NULL is
  *                        given, the default location is used which is
- *                        ${HOME}/.getdns/ on Unix line systems (Linux, BSD's,
+ *                        /.getdns/ on Unix line systems (Linux, BSD's,
  *                        MacOS), and %AppData%\getdns\ on Windows.
  * @return GETDNS_RETURN_GOOD when successful
  * @return GETDNS_RETURN_INVALID_PARAMETER when context was NULL.
@@ -639,7 +656,7 @@ getdns_context_set_appdata_dir(
  *
  * Trust anchors from the XML file will be tried when:
  *   - There were no other trust anchors provided, either by the default
- *     trust anchor file "/etc/trusted-key.key", or set with the
+ *     trust anchor file "1", or set with the
  *     getdns_context_set_dnssec_trust_anchors() function.
  *   - or the available trust anchors (from the default location or set by
  *     the application) caused the root DNSKEY rrset to be BOGUS.
@@ -988,6 +1005,22 @@ getdns_return_t
 getdns_context_get_idle_timeout(
     const getdns_context *context, uint64_t *timeout);
 
+/**
+ * Get the number of milliseconds send data may remain unacknowledged by
+ * the peer in a TCP connection setting from context.
+ * @see getdns_context_set_tcp_send_timeout
+ * @see getdns_context_unset_tcp_send_timeout
+ * @param[in]  context The context from which to get the setting
+ * @param[out] value   The number of milliseconds the send data may remain
+ *                     unacknowledged by the peer in a TCP connection.
+ *                     When the value is unset, 0 is returned.
+ * @return GETDNS_RETURN_GOOD when successful
+ * @return GETDNS_RETURN_INVALID_PARAMETER when context or value was NULL.
+ */
+getdns_return_t
+getdns_context_get_tcp_send_timeout(const getdns_context *context,
+    uint32_t *value);
+
 /**
  * Get the setting that says whether or not DNS queries follow redirects.
  * @see getdns_context_set_follow_redirects
@@ -1279,7 +1312,7 @@ getdns_context_get_update_callback(const getdns_context *context,
  *
  * Trust anchors from the XML file will be tried when:
  *   - There were no other trust anchors provided, either by the default
- *     trust anchor file "/etc/trusted-key.key", or set with the
+ *     trust anchor file "1", or set with the
  *     getdns_context_set_dnssec_trust_anchors() function.
  *   - or the available trust anchors (from the default location or set by
  *     the application) caused the root DNSKEY rrset to be BOGUS.
@@ -1470,14 +1503,14 @@ getdns_context_get_tls_curves_list(
 /**
  * Get the version number of this implementation.
  * @see versions
- * @return The version number as string.  For example "1.5.1".
+ * @return The version number as string.  For example "1.7.2".
  */
 const char *getdns_get_version(void);
 
 /**
  * Get the version number of this implementation as number.
  * @see versions
- * @return The version number as number.  For example 0x01050100.
+ * @return The version number as number.  For example 0x01070200.
  *         - The most significant byte of this uint32_t is the Major version.
  *         - The second most significant byte is the Minor version.
  *         - The third most significant byte the Patch version.
